@@ -95,6 +95,20 @@ parameter_field_schema = {
     "max": {"required": False, "type": "integer"},
     "min": {"required": False, "type": "integer"},
     "default": {"required": False},
+    "show_on": {
+        "type": "dict",
+        "required": False,
+        "schema": {
+            "parameter_name": {"type": "string", "required": True},
+            "parameter_value": {
+                "type": "list",
+                "schema": {
+                    "type": ["string", "boolean", "number", "integer", "date", "datetime"]
+                },
+                "required": True,
+            },
+        },
+    },
 }
 
 parameter_field_schema["parameters"] = {
@@ -189,7 +203,7 @@ def _get_shared_type_schema(name):
             "type": "string",
             "minlength": 8,
             "required": True,
-            "regex": r"^[A-Z\d]+-[A-Z\d]+$",
+            "regex": r"^[A-Z0-9]+([_-][A-Z0-9]+)*$",
         },
         "alias": {"type": "string", "required": True},
         "description": {"type": "string", "required": True},
@@ -225,7 +239,7 @@ connection_type_schema = {
         "type": "string",
         "minlength": 8,
         "required": True,
-        "regex": r"^[A-Z\d]+-[A-Z\d]+$",
+        "regex": r"^[A-Z0-9]+([_-][A-Z0-9]+)*$",
     },
     "alias": {"type": "string", "required": True},
     "description": {"type": "string", "required": True},
